prove

Function prove 

pub fn prove(
    gens: &PedersenGens,
    com: &PedersenCommitment,
    bits: u32,
) -> Option<PedersenRangeProof>
Prove that com opens to a value in [0, 2^bits).

Returns None when the value does not fit the bit width.